@@ -14,21 +14,33 @@
 #
 
 package GnuPG::UserId;
-use Moose;
-use MooseX::AttributeHelpers;
+use Any::Moose;
 
 has [qw( validity as_string )] => (
     isa => 'Any',
     is  => 'rw',
 );
 
-has $_ => (
+has signatures => (
     isa       => 'ArrayRef',
     is        => 'rw',
     default   => sub { [] },
-    metaclass => 'Collection::Array',
-    provides  => { push => 'push_' . $_ },
-) for qw(signatures);
+);
+has revocations => (
+    isa       => 'ArrayRef',
+    is        => 'rw',
+    default   => sub { [] },
+);
+
+sub push_signatures {
+    my $self = shift;
+    push @{ $self->signatures }, @_;
+}
+sub push_revocations {
+    my $self = shift;
+    push @{ $self->revocations }, @_;
+}
+
 
 # DEPRECATED
 sub user_id_string {
@@ -37,6 +49,8 @@ sub user_id_string {
     return $self->as_string();
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -86,6 +100,12 @@ See GnuPG's DETAILS file for details.
 A list of GnuPG::Signature objects embodying the signatures
 on this user id.
 
+=item revocations
+
+A list of revocations associated with this User ID, stored as
+GnuPG::Signature objects (since revocations are a type of
+certification as well).
+
 =back
 
 =head1 SEE ALSO
